from distutils.core import setup
setup(
    name="Tank Capacity", #发布包文件的名称
    version="2.0", # 发布包的版本号
    description="2020-08-20 by NORKHE" # 发布包的描述信息# 作者名称等等
    # py_modules = ['','',''] # 发布包中的模块文件列表
)